@@ -2,11 +2,10 @@
 
 '''
 
-from .pmc import *
-from .. import density
+from pypmc.mix_adapt.pmc import *
+from pypmc import density
 import numpy as np
 import unittest
-from nose.plugins.attrib import attr
 
 class TestGaussianPMCNoOverlap(unittest.TestCase):
     # proposal density
@@ -58,14 +57,14 @@ class TestGaussianPMCNoOverlap(unittest.TestCase):
                         [-10.4898097 ,   7.48668861,  -2.41443733]])
 
     def test_invalid_usage(self):
-        self.assertRaisesRegexp(ValueError, r'["\'` ]*rb["\'` ]*must.*["\' `]*True["\'` ]* if["\'` ]*latent["\'` ]*.*not',
-                                gaussian_pmc, self.samples, self.prop, self.weights, rb=False)
-        self.assertRaisesRegexp(ValueError, r'["\'` ]*mincount["\'` ]*must.*["\' `]*[0(zero)]["\'` ]* if["\'` ]*latent["\'` ]*.*not',
-                                gaussian_pmc, self.samples, self.prop, self.weights, mincount=10)
-        self.assertRaisesRegexp(ValueError, r'(["\'` ]*mincount["\'` ]*must.*["\' `]*[0(zero)]["\'` ]* if["\'` ]*latent["\'` ]*.*not)' + \
-                                            r'|' + \
-                                            r'(["\'` ]*rb["\'` ]*must.*["\' `]*True["\'` ]* if["\'` ]*latent["\'` ]*.*not)',
-                                gaussian_pmc, self.samples, self.prop, self.weights, mincount=10, rb=False)
+        self.assertRaisesRegex(ValueError, r'["\'` ]*rb["\'` ]*must.*["\' `]*True["\'` ]* if["\'` ]*latent["\'` ]*.*not',
+                               gaussian_pmc, self.samples, self.prop, self.weights, rb=False)
+        self.assertRaisesRegex(ValueError, r'["\'` ]*mincount["\'` ]*must.*["\' `]*[0(zero)]["\'` ]* if["\'` ]*latent["\'` ]*.*not',
+                               gaussian_pmc, self.samples, self.prop, self.weights, mincount=10)
+        self.assertRaisesRegex(ValueError, r'(["\'` ]*mincount["\'` ]*must.*["\' `]*[0(zero)]["\'` ]* if["\'` ]*latent["\'` ]*.*not)' + \
+                                           r'|' + \
+                                           r'(["\'` ]*rb["\'` ]*must.*["\' `]*True["\'` ]* if["\'` ]*latent["\'` ]*.*not)',
+                               gaussian_pmc, self.samples, self.prop, self.weights, mincount=10, rb=False)
 
     def test_mincount_and_copy(self):
         self.prop_weights = self.prop.weights.copy()
@@ -374,28 +373,27 @@ class TestGaussianPMCMultipleUpdates(unittest.TestCase):
         np.random.mtrand.seed(345985345634 % 4294967296)
 
     def test_invalid_usage(self):
-        self.assertRaisesRegexp(ValueError, r'["\'` ]*rb["\'` ]*must.*["\' `]*True["\'` ]* if["\'` ]*latent["\'` ]*.*not',
-                                PMC, self.samples, self.prop, self.weights, rb=False)
-        self.assertRaisesRegexp(ValueError, r'["\'` ]*mincount["\'` ]*must.*["\' `]*[0(zero)]["\'` ]* if["\'` ]*latent["\'` ]*.*not',
-                                PMC, self.samples, self.prop, self.weights, mincount=10)
-        self.assertRaisesRegexp(ValueError, r'(["\'` ]*mincount["\'` ]*must.*["\' `]*[0(zero)]["\'` ]* if["\'` ]*latent["\'` ]*.*not)' + \
-                                            r'|' + \
-                                            r'(["\'` ]*rb["\'` ]*must.*["\' `]*True["\'` ]* if["\'` ]*latent["\'` ]*.*not)',
-                                PMC, self.samples, self.prop, self.weights, mincount=10, rb=False)
+        self.assertRaisesRegex(ValueError, r'["\'` ]*rb["\'` ]*must.*["\' `]*True["\'` ]* if["\'` ]*latent["\'` ]*.*not',
+                               PMC, self.samples, self.prop, self.weights, rb=False)
+        self.assertRaisesRegex(ValueError, r'["\'` ]*mincount["\'` ]*must.*["\' `]*[0(zero)]["\'` ]* if["\'` ]*latent["\'` ]*.*not',
+                               PMC, self.samples, self.prop, self.weights, mincount=10)
+        self.assertRaisesRegex(ValueError, r'(["\'` ]*mincount["\'` ]*must.*["\' `]*[0(zero)]["\'` ]* if["\'` ]*latent["\'` ]*.*not)' + \
+                                           r'|' + \
+                                           r'(["\'` ]*rb["\'` ]*must.*["\' `]*True["\'` ]* if["\'` ]*latent["\'` ]*.*not)',
+                               PMC, self.samples, self.prop, self.weights, mincount=10, rb=False)
 
         invalid_density = None
 
-        self.assertRaisesRegexp(TypeError, r'.*density.*must be.*MixtureDensity',
-                                PMC, self.samples, invalid_density, self.weights)
+        self.assertRaisesRegex(TypeError, r'.*density.*must be.*MixtureDensity',
+                               PMC, self.samples, invalid_density, self.weights)
 
     def test_adaptation(self):
         pmc = PMC(self.samples, self.prop, self.weights, latent=self.latent, rb=False)
-        converged = pmc.run(verbose=True)
+        converged = pmc.run()
         outdensity = pmc.density
 
         self.assertEqual(converged, 2)
 
-    @attr('slow')
     def test_with_overlap(self):
         # proposal density
         mu1 = np.array([ 10.5,   1.1,   8.0])
@@ -422,7 +420,7 @@ class TestGaussianPMCMultipleUpdates(unittest.TestCase):
         samples, latent = target.propose(10**4, trace=True, shuffle=False)
 
         pmc = PMC(samples, prop, latent=latent, rb=True)
-        pmc.run(verbose=True)
+        pmc.run()
         adapted_prop = pmc.density
 
         adapted_comp_weights = adapted_prop.weights
@@ -438,7 +436,6 @@ class TestGaussianPMCMultipleUpdates(unittest.TestCase):
         np.testing.assert_allclose(adapted_sigma2      , cov2             , atol=0.06)
         # less samples from second component due to smaller component weight --> estimate less accurate
 
-    @attr('slow')
     def test_prune(self):
         # proposal density
         mu1 = np.array([ 10.5,   1.1,   8.0])
@@ -467,7 +464,7 @@ class TestGaussianPMCMultipleUpdates(unittest.TestCase):
 
         pmc = PMC(samples, prop, rb=True)
         pmc_prune = 0.5 / len(prop)
-        converge_step = pmc.run(30, verbose=True, prune=pmc_prune)
+        converge_step = pmc.run(30, prune=pmc_prune)
         adapted_prop = pmc.density
 
         adapted_comp_weights = adapted_prop.weights
@@ -489,7 +486,6 @@ class TestStudentTPMCMultipleUpdates(unittest.TestCase):
     def setUp(self):
         np.random.mtrand.seed(3026281795684 % 4294967296)
 
-    @attr('slow')
     def test_prune(self):
         # proposal density
         mu1 = np.array([ 10.5,   1.1,   8.0])
@@ -520,7 +516,7 @@ class TestStudentTPMCMultipleUpdates(unittest.TestCase):
 
         pmc = PMC(samples, prop, rb=True, mindof=mindof, maxdof=maxdof)
         pmc_prune = 0.5 / len(prop)
-        converge_step = pmc.run(30, verbose=True, prune=pmc_prune)
+        converge_step = pmc.run(30, prune=pmc_prune)
         adapted_prop = pmc.density
 
         adapted_comp_weights = adapted_prop.weights
