@@ -1,15 +1,14 @@
 """Unit tests for Variational Bayes.
 
 """
-from .variational import *
-from ..density.gauss import Gauss
-from ..density.student_t import StudentT
-from ..density.mixture import MixtureDensity, create_gaussian_mixture, recover_gaussian_mixture
-from ..sampler import importance_sampling
-from ..tools._probability_densities import unnormalized_log_pdf_gauss, normalized_pdf_gauss
+from pypmc.mix_adapt.variational import *
+from pypmc.density.gauss import Gauss
+from pypmc.density.student_t import StudentT
+from pypmc.density.mixture import MixtureDensity, create_gaussian_mixture, recover_gaussian_mixture
+from pypmc.sampler import importance_sampling
+from pypmc.tools._probability_densities import unnormalized_log_pdf_gauss, normalized_pdf_gauss
 
 import copy
-from nose.plugins.attrib import attr
 import numpy as np
 from scipy.special import digamma
 import unittest
@@ -81,19 +80,19 @@ class TestGaussianInference(unittest.TestCase):
         # alpha, m and W should be valid
         GaussianInference(data, components=2, alpha=alpha, m=m, W=W)
 
-        self.assertRaisesRegexp(ValueError, 'either.*components.*or.*initial_guess',
-                                GaussianInference, data)
+        self.assertRaisesRegex(ValueError, 'either.*components.*or.*initial_guess',
+                               GaussianInference, data)
 
         # should not be able to pass both initial_guess and something out of [alpha, beta, nu, m, W]
-        self.assertRaisesRegexp(ValueError, 'EITHER.*W.*OR.*initial_guess',
+        self.assertRaisesRegex(ValueError, 'EITHER.*W.*OR.*initial_guess',
                                GaussianInference, data, initial_guess=target_mix, W=W)
-        self.assertRaisesRegexp(ValueError, 'EITHER.*m.*OR.*initial_guess',
+        self.assertRaisesRegex(ValueError, 'EITHER.*m.*OR.*initial_guess',
                                GaussianInference, data, initial_guess=target_mix, m=m)
-        self.assertRaisesRegexp(ValueError, 'EITHER.*alpha.*OR.*initial_guess',
+        self.assertRaisesRegex(ValueError, 'EITHER.*alpha.*OR.*initial_guess',
                                GaussianInference, data, initial_guess=target_mix, alpha=alpha)
-        self.assertRaisesRegexp(ValueError, 'EITHER.*beta.*OR.*initial_guess',
+        self.assertRaisesRegex(ValueError, 'EITHER.*beta.*OR.*initial_guess',
                                GaussianInference, data, initial_guess=target_mix, beta=beta)
-        self.assertRaisesRegexp(ValueError, 'EITHER.*nu.*OR.*initial_guess',
+        self.assertRaisesRegex(ValueError, 'EITHER.*nu.*OR.*initial_guess',
                                GaussianInference, data, initial_guess=target_mix, nu=nu)
 
 
@@ -133,15 +132,15 @@ class TestGaussianInference(unittest.TestCase):
         np.testing.assert_almost_equal(re_component_weights, normalized_weights                  )
 
         # test default
-        self.assertRaisesRegexp(ValueError, 'Specify ``m``',
-                                GaussianInference, data, len(data) + 10)
+        self.assertRaisesRegex(ValueError, 'Specify ``m``',
+                               GaussianInference, data, len(data) + 10)
         # specify some m with too many components
         GaussianInference(data, len(data) + 10, m=np.zeros((len(data) + 10, 2)))
         GaussianInference(data, K)
 
         # test 'first'
-        self.assertRaisesRegexp(ValueError, 'either.*components.*or.*initial_guess',
-                                GaussianInference, data, initial_guess='first')
+        self.assertRaisesRegex(ValueError, 'either.*components.*or.*initial_guess',
+                               GaussianInference, data, initial_guess='first')
         vb = GaussianInference(data, K, initial_guess='first', alpha0=alpha0, beta0=beta0, nu0=nu0)
         np.testing.assert_equal(vb.m, data[0:K])
 
@@ -291,7 +290,6 @@ class TestGaussianInference(unittest.TestCase):
         W     = np.linalg.inv(inv_W)
         np.testing.assert_allclose(infer.W[0], W)
 
-    @attr('slow')
     def test_weighted(self):
         # this test uses pypmc.pmc.importance_sampling --> before debugging here,
         # first make sure that importance_sampling works
@@ -344,7 +342,7 @@ class TestGaussianInference(unittest.TestCase):
         samples = sam.samples[:]
 
         clust = GaussianInference(samples, 2, weights=weights, m=np.vstack((prop_mean1,prop_mean2)))
-        converged = clust.run(verbose=True)
+        converged = clust.run()
         self.assertTrue(converged)
 
         resulting_mixture = clust.make_mixture()
@@ -390,7 +388,6 @@ class TestGaussianInference(unittest.TestCase):
         # try creation of new GaussianInference instance with these values
         GaussianInference(samples, **posterior_as_prior)
 
-    @attr('slow')
     def test_prune(self):
         # generate test data from two independent gaussians
         target_abundances = np.array((.1, .9))
@@ -418,7 +415,7 @@ class TestGaussianInference(unittest.TestCase):
         # to result in same numbers, except it works also when
         # components were reduced => nsteps2 + 1
         eps = 1e-15
-        nsteps2 = infer2.run(20, verbose=True)
+        nsteps2 = infer2.run(20)
         self.assertEqual(nsteps2 + 1, nsteps)
 
         result2 = infer2.make_mixture()
@@ -473,14 +470,14 @@ class TestVBMerge(unittest.TestCase):
         means, _, _ = recover_gaussian_mixture(self.input_mix)
 
         # test default
-        self.assertRaisesRegexp(ValueError, 'Specify ``m``',
-                                VBMerge, self.input_mix, self.N, 32)
+        self.assertRaisesRegex(ValueError, 'Specify ``m``',
+                               VBMerge, self.input_mix, self.N, 32)
         # specify some m with too many components
         VBMerge(self.input_mix, self.N, 32, m=np.zeros((32, 1)))
         VBMerge(self.input_mix, self.N, K)
         # test 'first'
-        self.assertRaisesRegexp(ValueError, 'either.*components.*or.*initial_guess',
-                                VBMerge, self.input_mix, self.N, initial_guess='first')
+        self.assertRaisesRegex(ValueError, 'either.*components.*or.*initial_guess',
+                               VBMerge, self.input_mix, self.N, initial_guess='first')
 
 
         vb = VBMerge(self.input_mix, self.N, K, initial_guess='first')
@@ -493,7 +490,7 @@ class TestVBMerge(unittest.TestCase):
 
     def test_1d(self):
         vb = VBMerge(self.input_mix, N=self.N, initial_guess=self.initial_guess)
-        vb.run(verbose=True)
+        vb.run()
         mix = vb.make_mixture()
         self.assertEqual(len(mix), 1)
         # means agree as m0 = 0 but correction from beta0
@@ -609,7 +606,7 @@ class TestVBMerge(unittest.TestCase):
         # restart, should converge immediately
         pripos = vb.prior_posterior()
         vb2 = VBMerge(input_mix, vb.N, **pripos)
-        nsteps = vb2.run(verbose=True)
+        nsteps = vb2.run()
         self.assertEqual(nsteps, 1)
         self.assertEqual(vb2.likelihood_bound(), vb.likelihood_bound())
 
@@ -618,7 +615,6 @@ class TestVBMerge(unittest.TestCase):
         for k, v in params2.items():
             np.testing.assert_array_equal(v, pripos[k])
 
-    @attr('slow')
     def test_large_prune(self):
         #Compress large number of similar components into a single component.
 
@@ -699,7 +695,7 @@ class TestVBMerge(unittest.TestCase):
         # converge exactly in two steps
         # prune out one component after first update
         # then get same bound twice
-        self.assertEqual(vb.run(verbose=True), 2)
+        self.assertEqual(vb.run(), 2)
         self.assertEqual(vb.K, 1)
         res = vb.make_mixture()
         np.testing.assert_allclose(res.components[0].mu   , target_mean,  rtol=1e-3)
