@@ -2,10 +2,9 @@
 
 """
 
-from .markov_chain import *
-from .. import density
-from ..tools._probability_densities import unnormalized_log_pdf_gauss
-from nose.plugins.attrib import attr
+from pypmc.sampler.markov_chain import *
+from pypmc import density
+from pypmc.tools._probability_densities import unnormalized_log_pdf_gauss
 import numpy as np
 import unittest
 
@@ -94,7 +93,6 @@ class TestMarkovChain(unittest.TestCase):
 
         self.assertRaises(NotImplementedError, lambda: prop.evaluate(1.,2.))
 
-    @attr('slow')
     def test_sampling(self):
         delta_mean   = .002
         delta_var0   = .0003
@@ -144,7 +142,7 @@ class TestMarkovChain(unittest.TestCase):
 
         mc = MarkovChain(bad_target, prop, start)
 
-        self.assertRaisesRegexp(ValueError, 'encountered NaN', mc.run)
+        self.assertRaisesRegex(ValueError, 'encountered NaN', mc.run)
 
     def test_history(self):
         # dummy; not a real proposal
@@ -228,7 +226,6 @@ class TestAdaptiveMarkovChain(unittest.TestCase):
     def setUp(self):
         np.random.mtrand.seed(rng_seed)
 
-    @attr('slow')
     def test_adapt(self):
         delta_mean   = .005
 
@@ -360,7 +357,7 @@ class TestAdaptiveMarkovChain(unittest.TestCase):
         self.assertEqual(mc.force_acceptance_min   , test_value)
         self.assertEqual(mc.damping                , test_value)
 
-        self.assertRaisesRegexp(TypeError, r'keyword args only; try set_adapt_parameters\(keyword = value\)',
-                                mc.set_adapt_params, test_value)
-        self.assertRaisesRegexp(TypeError, r"unexpected keyword\(s\)\: ",
-                                mc.set_adapt_params, unknown_kw = test_value)
+        self.assertRaisesRegex(TypeError, r'keyword args only; try set_adapt_parameters\(keyword = value\)',
+                               mc.set_adapt_params, test_value)
+        self.assertRaisesRegex(TypeError, r"unexpected keyword\(s\)\: ",
+                               mc.set_adapt_params, unknown_kw = test_value)
