@@ -5,12 +5,11 @@ In order to run tests in parallel, you have to execute this test with
 '''
 
 import numpy as np
-from nose.plugins.attrib import attr
-from ..sampler.markov_chain import MarkovChain, AdaptiveMarkovChain
-from ..sampler.importance_sampling import ImportanceSampler
-from ..density.mixture_test import DummyComponent
-from .. import density
-from ._probability_densities import unnormalized_log_pdf_gauss
+from pypmc.sampler.markov_chain import MarkovChain, AdaptiveMarkovChain
+from pypmc.sampler.importance_sampling import ImportanceSampler
+from pypmc.density.mixture_test import DummyComponent
+from pypmc import density
+from pypmc.tools._probability_densities import unnormalized_log_pdf_gauss
 
 def setUpModule():
     try:
@@ -43,7 +42,6 @@ class TestMPISampler(unittest.TestCase):
     def setUp(self):
         np.random.mtrand.seed(rng_seed)
 
-    @attr('slow')
     def test_mc_self_adaptive_sampling(self):
         NumberOfRandomSteps = 20000
         delta_mean = .01
